@@ -36,6 +36,7 @@ BASE_COL_FIELDS = json.loads(os.getenv(f'{laskea.APP_ENV}_COL_FIELDS', json.dump
 BASE_COL_MAPS = json.loads(os.getenv(f'{laskea.APP_ENV}_COL_MAPS', json.dumps(KNOWN_CI_FIELDS)))
 BASE_JOIN_STRING = os.getenv(f'{laskea.APP_ENV}_JOIN_STRING', ' <br>')
 BASE_LF_ONLY = bool(os.getenv(f'{laskea.APP_ENV}_LF_ONLY', 'YES'))
+LF = '\n'
 
 
 def mock(number: int) -> int:
@@ -275,3 +276,145 @@ def markdown_heading(
         if not laskea.DRY_RUN:
             print(message, file=sys.stderr)
         return message
+
+
+@no_type_check
+def fetch_jql(handle: Jira, jql_text: str) -> dict:
+    """Expose the JIRA result structure directly."""
+    if not jql_text.strip():
+        return {
+            'jql_text': jql_text,
+            'error': 'Empty JIRA Query Language text detected',
+        }
+
+    try:
+        issues = handle.jql(jql_text, limit=1000)
+    except (HTTPError, RuntimeError) as err:
+        return {
+            'jql_text': jql_text,
+            'error': str(err),
+        }
+
+    return {
+        'jql_text': jql_text,
+        'data': issues,
+        'error': None,
+    }
+
+
+@no_type_check
+def parent_children_sections(
+    handle: Jira,
+    parent_jql: str,
+    children_jql: str,
+    parent_type_name: str,
+    children_type_name: str,
+    data: Mapping[str, Union[object, Iterable, Sized]] = None,
+) -> str:
+    """Create sub(sub)section level content representing the issue content from parent children filter results."""
+    if data is None:
+        data = {
+            'parent_data': fetch_jql(handle, jql_text=parent_jql),
+            'children_data': fetch_jql(handle, jql_text=children_jql),
+        }
+    if data['parent_data'].get('error', '') or data['children_data'].get('error', ''):
+        return json.dumps(data, indent=2)
+
+
+    doc = {}
+    has_parents = {}
+
+    for parent in data['parent_data']['issues']:
+        p_id = parent['id']
+        p_key = parent['key']
+
+        p_field = parent['fields']
+
+        p_itn = p_field['issuetype']['name']
+        #assert p_itn == parent_type_name
+        p_sum = p_field['summary']
+        p_des = p_field['description']  # None for parent type names
+        p_epic = p_field['customfield_10006']  # TODO assuming here ...
+        p_created = p_field['created']  # Textual timestamps like "2019-03-12T10:01:25.000+0100"
+        p_updated = p_field['updated']
+
+        doc[p_key] = {
+            'id': p_id,
+            'type': p_itn,
+            'summary': p_sum,
+            'description': p_des,
+            'epic': p_epic,
+            'created': p_created,
+            'updated': p_updated,
+            'children': {},
+        }
+
+        children = p_field['subtasks']
+
+        for child in children:
+            c_id = child['id']
+            c_key = child['key']
+
+            c_field = child['fields']
+
+            c_itn = c_field['issuetype']['name']
+            # assert c_itn == children_type_name
+            c_sum = c_field['summary']
+
+            doc[p_key]['children'][c_key] = {
+                'id': c_id,
+                'type': c_itn,
+                'summary': c_sum,
+                'description': None,
+                'created': None,
+                'updated': None,
+            }
+            if c_key not in has_parents:
+                has_parents[c_key] = []
+            has_parents[c_key].append(p_key)
+
+    for child in data['children_data']['issues']:
+        c_id = child['id']
+        c_key = child['key']
+
+        c_field = child['fields']
+
+        p_key = c_field['parent']['key']
+        # assert p_key in has_parents[c_key]
+        p_itn = c_field['parent']['issuetype']['name']
+        # assert p_itn == parent_type_name
+
+        c_itn = c_field['issuetype']['name']
+        # assert c_itn == children_type_name
+        c_sum = c_field['summary']
+        c_des = c_field['description']  # Table or list or notes for children type names
+        c_created = c_field['created']
+        c_updated = c_field['updated']
+
+        doc[p_key]['children'][c_key]['description'] = c_des
+        doc[p_key]['children'][c_key]['created'] = c_created
+        doc[p_key]['children'][c_key]['updated'] = c_updated
+
+    return doc_to_markdown(doc, parent_type_name, children_type_name)
+
+
+@no_type_check
+def doc_to_markdown(doc, parent_type_name: str, children_type_name: str) -> str:
+    """Transform the document content to markdown."""
+    md = []
+    for p_key, p_tree in doc.items():
+        p_head = f'## {parent_type_name} {p_tree["summary"].title()} ({p_key})'.strip(LF)
+        c_count = len(p_tree["children"])
+        p_para = f'The {p_tree["type"]} consists of {c_count} {children_type_name}{"" if c_count == 1 else "s"}'.strip(LF)
+
+        c_parts = []
+        for c_key, c_data in p_tree["children"].items():
+            c_head = f'### {children_type_name} {c_data["summary"].title()} ({c_key})'.strip(LF)
+            c_content = c_data["description"].strip(LF)
+            c_parts.extend([LF, c_head, LF, c_content])
+
+        md.extend([LF, p_head])
+        md.extend(c_parts)
+
+    md.append(LF)
+    return LF.join(md)
